#
# spec file for package python-traits
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         oldpython python
Name:           python-traits
Version:        5.1.1
Release:        lp151.1.1
Summary:        Explicitly typed attributes for Python
# Images have different licenses. For image license breakdown check
# image_LICENSE.txt file. Except enthought/traits/ui/editors_gen.py
# which is GPLv2+ all remaining source or image files are in BSD
# 3-clause license. Confirmed from upstream.
License:        BSD-3-Clause AND EPL-1.0 AND LGPL-2.1-only
Group:          Development/Libraries/Python
Url:            https://github.com/enthought/traits
Source:         https://files.pythonhosted.org/packages/source/t/traits/traits-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module nose}
# /SECTION
Requires:       python-numpy
Requires:       python-six
Recommends:     python-traitsui
%ifpython2
Provides:       %{oldpython}-Traits = %{version}
Obsoletes:      %{oldpython}-Traits < %{version}
%endif

%python_subpackages

%description
The traits package developed by Enthought provides a special type definition
called a trait. Although they can be used as normal Python object attributes,
traits also have several additional characteristics:

 * Initialization: A trait can be assigned a default value.
 * Validation: A trait attribute's type can be explicitly declared.
 * Delegation: The value of a trait attribute can be contained either
   in another object.
 * Notification: Setting the value of a trait attribute can trigger
   notification of other parts of the program.
 * Visualization: User interfaces that permit the interactive
   modification of a trait's value can be automatically constructed
   using the trait's definition.

Part of the Enthought Tool Suite (ETS).

%prep
%setup -q -n traits-%{version}
%fdupes examples/
# file not utf-8
iconv -f iso8859-1 -t utf-8 image_LICENSE_Eclipse.txt > image_LICENSE_Eclipse.txt.conv
mv -f image_LICENSE_Eclipse.txt.conv image_LICENSE_Eclipse.txt

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%{python_expand mkdir tester_%{$python_bin_suffix}
pushd tester_%{$python_bin_suffix}
export PYTHONPATH=%{buildroot}%{$python_sitearch}
$python -m nose.core -v traits
popd
}

%files %{python_files}
%defattr(-,root,root,-)
%doc CHANGES.rst README.rst
%doc examples/
%license LICENSE.txt image_LICENSE*.txt
%{python_sitearch}/traits/
%{python_sitearch}/traits-%{version}-py*.egg-info

%changelog
* Tue Apr 23 2019 pgajdos@suse.com
- version update to 5.1.1
  * Revert a change (#449) which accidentally broke external uses of
    ``_py2to3.str_find`` and ``_py2to3.str_rfind``. (#472)
* Wed Apr 17 2019 pgajdos@suse.com
- version update to 5.1.0
  * Make UUID trait initializable. (#459)
  * Change default ``FileEditor`` behavior for a ``File`` trait based on
    whether ``exists=True`` is specified for that trait. (#451, #467)
  * The changes made in #373 to make dynamically-added traits pickleable have
    been reverted. (#462)
  * ``traits.api.python_version`` has been removed. Internals have been
    refactored to use ``six.PY2`` in preference to ``sys.version_info``.
    (#449)
  * Don't depend on the 3rd party ``mock`` library on Python 3; use
    ``unittest.mock`` instead. (#446)
- Drop no longer needed avoid_sys_modules_hackery.patch
* Thu Feb 21 2019 Todd R <toddrme2178@gmail.com>
- Add avoid_sys_modules_hackery.patch
  Fixes building with latest numpy
  see: gh#enthought/traits#441
* Wed Feb  6 2019 Todd R <toddrme2178@gmail.com>
- Update to 5.0.0
  + highlights of this release are
  * Removal of 2to3 fixers and the use of six to provide Python 2/3 compatibility
  * Removal of deprecated `traits.protocols` submodule and related utils.
  * New `HasRequiredTraits` class
  * Better IPython tab completion for `HasTraits` subclasses
* Wed May  9 2018 toddrme2178@gmail.com
- Use license tag
* Wed Aug 23 2017 toddrme2178@gmail.com
- Implement single-spec version
- Update to version 4.6.0
  Highlights of this release include:
  * support for Python 3.4 and 3.5.
  * new Bytes and ValidatedTuple traits.
  * a new ArrayOrNone trait which correctly handles None comparisons with Numpy
    arrays.
  * clean-up of the ETSConfig code for TraitsUI toolkit selection.
  * better compatibility with NumPy scalar types.
  * many other bugfixes and improvements.
* Mon Oct 13 2014 toddrme2178@gmail.com
- Updated to version 4.5.0
  + Traits is now compatible with Python 3!
    The library now supports Python 3.2 and 3.3 .
  + The release also includes increased code coverage and automatic
    coverage report through coveralls.io .
  + Enhancements
  * Test files cleanups (#108, #111, #121)
  * Add automatic coverage reports (#110, #122)
  * Removed obsolete code (#109, #112, #113)
  * Increased test coverage (#114, #118)
  * Python 3 support (#115).  Thanks Yves Delley.
  * Allow setting and resetting the global adaptation manager (#145)
  * Various documentation improvements (#132, #133, #148, #154).
  + Changes
  * The Int trait type now accepts Python ints *and* Python longs, as well as
    instances of any Python type that implements the `__index__` method.
    Previously, long instances were not accepted. (#104, #123).
  + Fixes
  * Fix crash when trying to validate a property that has been deleted. (#138)
  * Fix clearing exception when raising a TraitError (#119)
  * Fix automatic adaptation when assigning to List trait (#147)
  * Fix some ctraits refcounting and exception clearing bugs (#48).  Thanks Yves
    Delley.
- Updated to version 4.4.0
  + The major new feature in this release is a new adaptation mechanism in the
    ``traits.adaptation`` package.  The new mechanism is intended to replace the
    older traits.protocols package.  Code written against ``traits.protocols`` will
    continue to work, although the ``traits.protocols`` API has been deprecated,
    and a warning will be logged on first use of ``traits.protocols``.  See the
    'Advanced Topics' section of the user manual for more details.
  + The release also includes improved support for using Cython with `HasTraits`
    classes, some new helper utilities for writing unit tests for Traits events,
    and a variety of bug fixes, stability enhancements, and internal code
    improvements.
  + New features
  * The adaptation mechanism in Traits, formerly based on the 'traits.protocols'
    package, has been replaced with the more robust 'traits.adaptation'
    package. (#51)
  * Added utility function for importing symbols (name, classes, functions)
    by name: 'traits.util.api.import_symbol'. (#51)
  * Users can set a global tracer, which receives all traits change events:
    `traits.trait_notifiers.set_change_event_tracers`. (#79)
  + Enhancements
  * Update benchmark script. (#54)
  * traits.util.deprecated: use module logger instead of root logger. (#59)
  * Provide an informative message in AdaptationError. (#62)
  * Allow HasTraits classes to be cythonized. (#73)
  * Improve tests for cythonization support. (#75)
  * Extending various trait testing helpers (#53)
  + Refactoring
  * The Traits notification code has been reworked to remove code duplication,
    and test coverage of that code has been significantly improved. (#79)
  + Fixes
  * Fix race condition when removing a traits listener. (#57)
  * Fix ugly interaction between DelegatesTo change handlers, dynamic change
    handlers and two levels of dynamic intialization. (#63)
  * Use a NullHandler for all 'traits' loggers. (#64)
  * Fix race condition in TraitChangeNotifyWrapper.listener_deleted (#66)
  * Fix leaking notifiers. (#68)
  * Fix failing special instance trait events. (#78)
  * Fix hiding KeyError exception inside trait default initialize method.
    (#81)
  * Fix Adapter object initialization. (#93)
  * Fix cyclic garbage arising from use of the WeakRef trait type. (#95)
  * `TraitSetObject.copy` now returns a plain rather than an
    uninitialized `TraitSetObject` instance. (#97)
  * Fix cyclic garbage arising from dynamic trait change handlers. (#101)
- Updated source to pypi url.
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Sat Apr 20 2013 toddrme2178@gmail.com
- Added a note about being part of the Enthought Tool Suite (ETS).
* Thu Apr 18 2013 toddrme2178@gmail.com
- Update to 4.3.0
  * no changelog
* Tue Jun 26 2012 toddrme2178@gmail.com
- Fix building on SLE 11
* Tue May 22 2012 toddrme2178@gmail.com
- changed name to python-traits to match upstream naming
- updated to version 4.2.0
- updated to version 4.1.0
* Sat Jun 25 2011 ocefpaf@yahoo.com.br
- updated to version 4.0.0
- The 'enthought' namespace has been removed For example:
  from enthought.traits.api import HasTraits
  is now simply:
  from traits.api import HasTraits
* Tue May 31 2011 saschpe@suse.de
- Spec file cleanup:
  * Removed unused script code
  * README.txt and LICENSE.txt belong into the base package
  * Proper SUSE version checks for fdupes, fixes SLE build
  * Added license header
* Sun Mar 20 2011 ocefpaf@yahoo.com.br
- first import from Fedora src rpm
